Introduction
============

.. include:: ../../../includes/global.rst

``debops.debops_api`` can be used to setup the `DebOps API`_.


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.0.0``. To install it, run::

    ansible-galaxy install debops.debops_api

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
